@@ -62,12 +62,12 @@ our @EXPORT_OK = qw{&logmsg &logmess &msg &json};
 
 use overload ('""' => \&to_json);
 
-use Log::Message::JSON::Hash;
+use Tie::IxHash;
 use Carp;
 
 #-----------------------------------------------------------------------------
 
-our $VERSION = '0.30.01';
+our $VERSION = '0.01';
 
 #-----------------------------------------------------------------------------
 
@@ -100,8 +100,7 @@ future and choose one for whole application).
 
 These functions accept either a reference to a hash or a list of
 C<< key => value >> pairs. The latter form preserves keys order, so I believe
-it's more useful. Also, in the latter form you may skip the first key name;
-the value will be stored under C<message> key in such case.
+it's more useful.
 
 Returned value is an object created with C<new()> method (see
 L</"Object-Oriented API">), so it's a reference to a hash (blessed, but still
@@ -114,12 +113,10 @@ Usage example:
 
   my $msg1 = logmsg { key1 => 1, key2 => 2 };
   my $msg2 = logmsg foo => 1, bar => 2, text => "some text";
-  my $msg3 = logmsg "my log message", host => hostname();
 
   my $logger = Log::Log4perl->get_logger();
   $logger->info($msg1);
   $logger->debug($msg2);
-  $logger->warn($msg3);
 
   print $msg1;
   printf "%s => %s\n", $_, $msg2->{$_} for keys %$msg2;
@@ -163,13 +160,12 @@ sub msg {
 Constructor.
 
 This method creates a new hash reference. The underlying hash is tied to
-L<Tie::IxHash(3)> (actually, to a proxy class that uses L<Tie::IxHash(3)> as
-a backend) and filled with arguments. Because of overloaded stringification
-operator, reference is blessed with Log::Message::JSON package.
+L<Tie::IxHash(3)> and filled with arguments. Because of overloaded
+stringification operator, reference is blessed with Log::Message::JSON
+package.
 
 If the first call form (list of pairs) was used, the order of key/value pairs
-is preserved. If the number of elements is odd, the first element is believed
-to be value of C<message> key.
+is preserved.
 
 If the second call form (hashref) was used, key/value pairs are sorted using
 C<cmp> operator, unless the referred hash was tied to L<Tie::IxHash(3)>.
@@ -179,7 +175,7 @@ C<cmp> operator, unless the referred hash was tied to L<Tie::IxHash(3)>.
 sub new {
   my ($class, @args) = @_;
 
-  tie my %self, 'Log::Message::JSON::Hash';
+  tie my %self, 'Tie::IxHash';
 
   if (@args == 1 && (ref $args[0] eq 'HASH' || eval {$args[0]->isa('HASH')})) {
     if (eval { tied(%{ $args[0] })->isa("Tie::IxHash") }) {
@@ -191,11 +187,7 @@ sub new {
     }
   } else {
     # keep the order
-    if (@args % 2 == 1) {
-      %self = ("message", @args);
-    } else {
-      %self = @args;
-    }
+    %self = @args;
   }
 
   return bless \%self, $class;
@@ -207,27 +199,20 @@ sub new {
 #
 #-----------------------------------------------------------------------------
 
-=begin Test::Pod::Coverage
-
-=item C<quote()>
-
-Helper function for quoting strings in JSON.
-
-=end Test::Pod::Coverage
-
-=cut
-
 sub quote($) {
   my ($str) = @_;
 
   my %q = (
     "\\" => "\\\\",
     '"'  => '\"',
+    "'"  => "\\'",
     "\n" => "\\n",
     "\r" => "\\r",
     "\t" => "\\t",
   );
-  $str =~ s/([\\"\n\r\t])/$q{$1}/g;
+  my $q = join "", keys %q;
+  $q = qr/[$q]/;
+  $str =~ s/($q)/$q{$1}/g;
 
   return $str;
 }
@@ -247,17 +232,10 @@ sub to_json($) {
   my ($value) = @_;
 
   if (ref $value eq __PACKAGE__) { # plain hash, tied
-    my $tied = tied %$value;
-
-    # store cache for this object if there was no cache for it
-    if (not defined $tied->cache) {
-      my @pairs = map {
-        sprintf '%s:%s', to_json($_), to_json($value->{$_})
-      } keys %$value;
-      $tied->cache(sprintf "{%s}", join ",", @pairs);
-    }
-
-    return $tied->cache;
+    my @pairs = map {
+      sprintf '%s:%s', to_json($_), to_json($value->{$_})
+    } keys %$value;
+    return sprintf "{%s}", join ",", @pairs;
   } elsif (ref $value eq "HASH") { # plain hash
     my @pairs = map {
       sprintf '%s:%s', to_json($_), to_json($value->{$_})
@@ -284,40 +262,6 @@ sub to_json($) {
 
 #-----------------------------------------------------------------------------
 
-=head1 C<die()> NOTES
-
-To use Log::Message::JSON as a reason for C<die()>, you need to assign it to
-C<$@> variable and call C<die()> without arguments (works for Perl 5.8+).
-
-  unless (open my $f, "<", $file) {
-    $@ = msg "error opening file",
-             filename => $file,
-             error => "$!", errno => $! + 0;
-    die;
-  }
-
-Of course just calling C<die(msg(...))> will work as well, but it will result
-in a message without end-of-line character.
-
-=begin Test::Pod::Coverage
-
-=item C<PROPAGATE($file, $line)>
-
-B<SEE ALSO>: C<perldoc -f die>
-
-=end Test::Pod::Coverage
-
-=cut
-
-
-sub PROPAGATE {
-  my ($self, $file, $line) = @_;
-
-  return sprintf "died at %s line %d, %s\n", $file, $line, $self;
-}
-
-#-----------------------------------------------------------------------------
-
 =head1 C<Log::Log4perl> NOTES
 
 You might be tempted to use custom I<message output filter> to stringify the
@@ -357,8 +301,7 @@ See http://dev.perl.org/licenses/ for more information.
 =head1 SEE ALSO
 
 L<Log::Log4perl(3)>, L<Log::Log4perl::Appender::Fluent(3)>,
-L<Log::Message::JSON::Hash(3)>, L<Tie::IxHash(3)>,
-L<Log::Message::Structured(3)>.
+L<Tie::IxHash(3)>, L<Log::Message::Structured(3)>.
 
 =cut
 
